% Notes on proposed analysis for workshop 'How are competitive interactions influenced by traits? A global analysis based on tree radial growth'
% Georges Kunstler

## Department of Biological Sciences Macquarie University, Sydney, NSW / Irstea EMGR Grenoble France <georges.kunstler@gmail.com>

# Workshop at Macquarie University 16-20 September 2013


# Introduction

## Background & motivation 

It is widely assumed that ecologically similar species compete more intensely for resources than dissimilar species, and therefore are less likely to coexist locally (competition-niche similarity hypothesis, MacArthur & Levins 1967). One way to quantify ecological similarity between species is via traits, such as leaf, seed and wood characteristics (Westoby et al. 2002). Traits influence many aspects of plant performance, including resource acquisition, thus higher traits dissimilarity should results in higher resource partitioning at local scale and less intense competition. 

The idea that species with more similar traits compete more intensely with one another underlies numerous ecological analyses (e.g. Kraft et al. 2008; Cornwell & Ackerly 2009). However this assumption has rarely been tested against field or experimental outcomes. This is surprising because it is well known that competitive interactions among vascular plants are more complex. For instance, the ranking of competitive ability for a common limiting resource is also an important driver of competitive interaction, e.g. via  competition for light. If ranking processes are dominant, competitive outcomes should be more closely related to the hierarchy (or the hierarchical distance) of relevant functional traits (Mayfield & Levine 2010; Kunstler et al. 2012) than trait dissimilarity. 

We recently analysed competitive interactions at local scale  between individual trees (using growth analysis with local competition index) to test these two contrasting assumptions in mountain forests in the French Alps (Kunstler et al. 2012). This analysis showed that competitive interactions at local scale were not driven by trait similarity, as commonly assumed, but rather by hierarchical measures. This support the idea that there are limited resource partitioning at the local scale between tree species (Sears & Chesson 2007). The lack of evidence of resource partitioning promoting traits diversity at local scale doesn't means that stabilizing frequency dependence is absent at all scale (there is other stabilizing process that operate at other scale).

## Objective
Given the importance in the ecological literature of the idea that trait similarity drives competitive interaction, we would like to extend our recent analysis to other forest ecosystems around the world. There are several datasets from national forest inventories or from long term permanent plots that report individual tree growth that can be combined with data about species functional traits sourced locally or from global databases (e.g. TRY). Accordingly, we are organising a working group to test several hypothesis of how traits influence the outcome of competition in multiple sites around the world. Invitees to the working group are proprietors or curators of key datasets.

## Overview of the analysis
Initially, we will apply the framework of Kunstler et al. (2012). A competition index is calculated that measures the reduction in growth of a target tree by other trees in their local neighbourhood. Within this competition index we will first compare two alternative models linking traits to competitive outcomes: 

(@) The competitive effect of species $b$ on species $a$ is a function of the absolute distance of their traits ($|t{_b} - t{_a}|$) as classically proposed;

(@) The competitive effect of species $b$ on species $a$ is a function of a hierarchical distance ($t_{b} - t_{a}$); 

The question is which of these assumptions provides a better prediction, and which traits contribute strongly. 

Our main aim is for the meeting is to actually carry out the proposed analysis and rough out a first-draft paper. A second step that I hope to start during or before the workshop is to include in the analysis additional test of stabilizing frequency dependence that operate at larger spatial scale (see section  Test of stabilizing frequency dependence processes at non local scale). In addition  we would be happy for other analyses and questions to also be considered, following group discussion.


## Output
The proposed analysis will give rise to a strong collaborative paper assessing, across a range of vegetation types, whether competitive interactions are better predicted from trait absolute distance, as is widely assumed, or from hierarchical relations, or other more complex models. Our aim is to run the analysis and draft a first version of the paper during the workshop or soon after.

----

## ADDITIONAL ANALYSIS: Test of stabilizing frequency dependence processes at non local scale 

Showing that competition in late successional stage is driven by hierarchical traits distance and not traits absolute distance is an important results because it shows that the classical assumption that trait differences reflect local resource partitioning is not supported by field data for forest ecosystems. However this leaves open the question of what process is promoting the diversity of traits observed in most forest communities (or why the community is not composed only of competitive species). Any trait is probably related to both competitive exclusion at local scale but also stabilizing effect at larger scale to explain the diversity of traits observed (Adler et al. 2013). One of the most classical coexistence mechanism in forest community is successionnal niche segregation. In that case,  trait value that results in a high competitive ability in late successional stage results in poor competitive ability in early successional stage and thus successional dynamics may promotes species coexistence. 
<!-- In the framework of Alder et al. 2013, however the successional process related to species shade-tolerance is presented within the spatial heterogeneity effect that promotes coexistence (spatial heterogeneity). According to this paper the key test would show that *"the covariance between the Environmental effect E and the competition effect C increase with increasing traits difference between the focal species and the rest of the community"*. This however unclear for me. Indeed as explained by Gravel et al. 2010, the spatial storage effect can not directly be related to the mosaic of gap in a forest because the variable light availability is in fact related to competition. In Chesson theory the spatial variability has to be related to environmental variable different than competition (see Gravel et al. 2010 Oikos). --> Gravel et al. propose that the shade tolerance (low light survival $vs.$ high light growth  can promotes species coexistence through three different mechanisms: 'relative non linearity' (relative non linearity in the response of the species to light results in one species dominating in constant environment and an other in a variable environment through the Jensen' inequality), the 'successional niche' (disturbance may promotes an inferior competitors at late successional stage because of its advantage in early successional stage) and the 'storage effect'  (in this case either through spatial variability in disturbance intensity or frequency or spatial variability of soil fertility). Gravel et al. 2010 shows that the low-light survival $vs.$ high light growth can support a relatively limited number of coexisting species (2 and sometime 3 - more than 3 have not been explored). This agree roughly with the number of SLA type supported in Daniel Falster model. Explanation for a higher diversity probably require additional mechanisms, for instance the spatial storage effect.

***The key question here is should we try to add an additional analysis to test what is promoting the diversity of traits despite the fact that late successional competitive ability is monotonically related to species trait (hierarchical trait distance).***

Potential analysis to add:

* **Successional niche**: Low competition (i.e. high light) growth rate of small tree is inversely related to traits that promote competitive ability in late successional stage. Under this analysis high light growth rate determine the competitive ability in early successionnal stage. However this assumption lack formal theoretical model showing what range of traits diversity may be promoted by this process (expect Daniel Falster model). <!-- We know that temporal variability of light/competition created by disturbance can only promotes the coexistence of two extremes type of species in a single isolated patch (Chesson 1994 and Gravel et al. 2010 this may promote only the two extremes strategies). In meta-community of patches connected by dispersal with disturbance this can promotes 3 species according to Gravel et al. 2010 (but in the special case of perfectly asynchronous disturbances), but we don't know if this can promotes a large traits diversity. Daniel Falster model predict the coexistence of up to 4 SLA type via this process (but more likely 3). --> ANALYSIS: Does trait related to competitive ability in high competition is inversely related to juvenile growth in low competition?

* **Spatial storage effect**: *2 points to test.* 1. the covariance between Competition $C$ and the environment effect $E$ is higher for species with trait value linked with a high competitive ability that for species with trait value linked to a low competitive ability (the environment effect can be estimated by the random plot effect or by the abiotic variables or both) (see Sears & Chesson 2007 Ecology for a test with annual plant). 2. species with low competitive ability traits have a different response to the environment (E) than species with high competitive ability traits. Analysis: from estimated growth model compute $cov(E,C)$ (for each plot E= random plot effect + abiotic effect) (C average competition experienced by the species on the plot)  and test how this is related to the trait linked to competitive ability. Then test if the dissimilarity in environmental response between species increase with traits distance between species (cov($E_1$,$E_2$) ~ abs($E_1$,$E_2$)).

----


# Analysis
Diameter growth of individual $i$ of species $a$ in plot $p$ will be analysed as a function of the effect of the size (diameter $D$), local abiotic variables ($A_1$, $A_2$) and a competition index based on the local basal area with distinct competitive effect for each competitive species $b$ ($\lambda_{a,b}$) using this general function:

\begin{equation} \label{eq:G1} 
G_{i,a,p} = \alpha_{a,p} f_1(D) f_2(A_1) f_3(A_2) g(\sum_{b=1}^{K} \lambda_{a,b} \times B_b)
\end{equation}

* With $f_1$, $f_2$, $f_3$ and $g$ function that represent the effcet of respectively $D$ $A_1$ and $A_2$ and competition on growth.

* Where $B_b=\sum_{n=1}^{N_{i,b}} {D_n^2 \pi /4}$ is the sum of the basal area of tree from species $b$ in the neighbourhood of the individual $i$. The neighbourhood will be either the whole plot for small forest inventory plot, or a radius (for instance 15m but we need to discuss that) in large tropical plot with X Y coordinates of all individuals.

* The observation error will be assumed to follow a log-normal distribution ($\sigma_o$).  $\alpha_{a,p}$ is a parameter describing growth of species $a$ with  a plot effect $p$ (and individual effect $i$ if multiple measurements) to account to repeated observation on the same plot (or quadrat in large plot).

## We can use several potential form for the functions $f$ and $g$

* The most simple model is a log-linear model

\begin{equation}
log(G_{i,a,p}) = log(\alpha_{a,i,p})+{\beta_{1,a}} \times log(D) +{\beta_{2,a}} \times log(A_1) +{\beta_{3,a}} \times log(A_2) + log( \sum_{b=1}^{K}{ {\lambda_{a,b}} \times log(B_b+1)}
\end{equation}\label{eqG2}


* In Kunstler et al. 2012 I used 

\begin{equation} \label{eq:G1} 
G_{i,a,p} = \frac{\alpha_{a,p} D^{\beta_{1,a}} A_1^{\beta_{2,a}} A_2^{\beta_{3,a}}}{1+\sum_{b=1}^{K} \lambda_{a,b} \times B_b}
\end{equation}

* In Caspersen et al. 2011 the following function for the competition function $g$ is used:
\begin{equation} 
\theta +(1-\theta) \times exp(-\sum_{b=1}^{K} \lambda_{a,b} \times B_b)
\end{equation}

* Then for the diameter effect we can explore more complex function such as (allowing for growth decrease at large diameter):
\begin{equation} 
e^{-\frac{1}{2}(\frac{ln(D/\delta)}{\sigma})^2}
\end{equation}

In all case the species specific parameters ($\alpha_{a,p}$, $\beta_{1,a}$, $\beta_{2,a}$, $\beta_{3,a}$ in loglinear model for instance) will be constrained  by a normal hyper-distribution.  We will use the same $\sigma_i$ and  $\sigma_p$ over all species [but se Ghislain comment on potential problem related to that].

Then as explained in the [section Overview](#overview) we will test different assumption about how the parameter $\lambda_{a,b}$ relate to the traits $t$, testing several alternative traits. First we will test the assumption that competitive effect of species $b$ on species $a$ is a function of the absolute distance of their traits with

\begin{equation} 
\lambda_{a,b} =  f(a + b \times |t_{b} - t_{a}|)
\end{equation}

with $f$ a function from $R$ to $R^{+}$ for competition model as in Caspersen et al. 2011 or Kunstler et al. 2012 or identity if loglinear model.


The species trait $t_a$ (log scale) will be assumed to be taken in a normal distribution with either the mean of the species observations and of $\sigma$ the  mean $\sigma$  within tree species reported for all species in TRY by Kattge et al. (2011) or the mean genus observation (if no species data are available) with $\sigma$ the mean $\sigma$ within all genus in TRY.

Then we will test the assumption that the competitive effect of species $b$ on species $a$ is a function of a hierarchical distance
\begin{equation} 
\lambda_{a,b} = f(a +b \times (t_{b} - t_{a}))
\end{equation}

* For the function $f$ from $R$ to $R^{+}$ we can use different alternative.
    + use exponential transformation of lambda this assume an expo shape of $\lambda$ in function of traits distance $exp( a +b \times (t_{b} - t_{a}))$.
    + Or use a logistic function multiplied by a constant giving the average competitive ability (so $\lambda$ will vary between 0 and 1) such as
\begin{equation}
\lambda_{a,b} = \frac{C}{1+  \exp(b \times (t_{b} - t_{a}))}
\end{equation}
 with $C$ a positive parameter representing the average competition and $b$ is a parameter to be estimated.


## Issue with species missing traits observation

In the computation of the competition index traits observations need to cover all species found in the neighbourhood. Rare species, particularly in tropical forest are likely to represent an issue. One solution would be as done in Aubry-Kientz et al. (2013) to assume that because of phylogenetic conservatism species with unknown trait value can be affected trait with a normal distribution of mean, the mean of the genus and $\sigma$, the $\sigma$ of the genus observation (or the mean genus $\sigma$ reported by Kattge et al. (2011) if to few observations in the genus). I'm reluctant to use family level.


## Issue with Eco-region

For large NFI data we will  run the analysis separately per ecoregion. If some ecoregion have too few observation will merge them with the most similar other ecoregion. 


# Table of data for the analysis and indication on the progress in formatting

-------------------------------------------------------------------------------------------------------------------------------
        Data.name             Demographic.data             Traits.data                 Availability          Abiotic.variables 
-------------------------- ---------------------- ----------------------------- --------------------------- -------------------
           BCI                   Large plot            Available with data                  ok                Topography soil  

          Fushan                 Large plot            Available with data                  ok                Topography soil  

         Luquillo                Large plot            Available with data        Wait Uriarte email          Topography soil 

        La Chonta                Large plot           Available by Lourens      Wait plot data availability   Topography soil 

         Paracou                 Large plot            Available with data                  ok                Topography soil 

          Mbaiki                 Large plot            Available with data                  ok                Topography soil

           FIA             Forest inventory plots              TRY                         data                   climate      

          Canada           Forest inventory plots              TRY                         data                   climate      

          France           Forest inventory plots              TRY                         data                 climate soil    

          Spain            Forest inventory plots              TRY                         data                   climate      
                                                                                                                
          Sweden           Forest inventory plots        Same as France                     Ok                    climate      

       Switzerland         Forest inventory plots        Same as France                     ok                    climate      

       New Zealand         Forest inventory plots Landcare but TRY data request            data                   climate      
                                                             as well                                                           

Autralia NSW Kooyman plots   Medium size plots        Available but no LMA                 data                   climate      
                                                       (requested to TRY)                                                      

       CSIRO plots           Medium size plots            NO LEAF TRAITS                    OK                    climate         
-------------------------------------------------------------------------------------------------------------------------------

<!-- I have the data for Spain, US, France, New Zealand (old data from David), NSW. -->

# Indication on data formatting

##  Tree growth data

Table with for each individual tree

- individual identifier
- species
- diameter at census 1
- growth between census or diameter at census 2
- plot identifier 
- [For large plots] quadrat identifier within the plot or X Y coordinates (to compute local competition index)
- plot or quadrat size
- plots coordinates
- individual weight if sampling weight vary between individuals (generally inverse of sampling plot size to compute basal area per hectare)
- historical disturbance and harvesting variables (to be able to select plots with no harvesting or major disturbance)
- abiotic variable on the quadrat or plot if available. This needs to be discussed (climate or soil/topo).
What are the key abiotic variables that are likely to influence growth in this data and that we need to control for. I was thinking of climatic variable for NFI and topographic and soil variable in large tropical forest plots. For the NFI data type, if possible please could you provides the climatic variables (average annual temperature and sum of precipitation and if possible PET) from the best source of data available for your country for each plot?

If multiple census repeats lines for each individuals.

In addition, if there is some tree height measurements it would be nice to keep this variable to compute the maximum height of each species (probably much better than the value in traits data base such as TRY)

## Trait data
- LMA
- Leaf N per mass
- Seed Mass
- Maximum height
- Wood density

If possible keep multiple observations per species if available to compute the $\sigma_t$.

## Ecoregion for NFI data
For the NFI data we will divide the data set by regions with similar ecological conditions. This will allow to estimate the link between competitive interactions and traits within regions of similar conditions and see how the results vary (for instance in the US there is a large variability between the north and the south). This will allow to make comparison with large tropical plot more easy. Then this will help to have smaller data set to speed up the estimation. Please could you either provides a source of ecoregion with a GIS layer that we can use or better directly includes this variable in the data (at the plot level). Similarly in term of climatic variables I was planning to use the best variables available for each data rather than a global data base of lower quality. Could you either give the link of such a data set or better directly do get the variables for each plot.

<!-- FOR THE US : There are at least a couple different delineations of ecoregions for Canada and the US. Here are a couple possibilities: http://www.epa.gov/wed/pages/ecoregions/na_eco.htm or  -->
<!-- http://www.fs.fed.us/rm/ecoregions/products/map-ecoregions-north-america/ -->

# References
Adler, P.B., Fajardo, A., Kleinhesselink, A.R., and Kraft, N.J.B. 2013. Trait-based tests of coexistence mechanisms. Ecology Letters early view.

Aubry-Kientz, Mélaine, Bruno Hérault, Charles Ayotte-Trépanier, Christopher Baraloto, and Vivien Rossi. 2013. Toward Trait-Based Mortality Models for Tropical Forests. PLoS ONE 8 (5) (May 13): e63678.

Cornwell, W.K., Ackerly, D.D., 2009. Community assembly and shifts in plant trait distributions across an environmental gradient in coastal California. Ecological Monographs 79, 109–126.

Gamfeldt, L., Snäll, T., Bagchi, R., Jonsson, M., Gustafsson, L., Kjellander, P., Ruiz-Jaen, M.C., Fröberg, M., Stendahl, J., Philipson, C.D., 2013. Higher levels of multiple ecosystem services are found in forests with more tree species. Nature Communications 4, 1340.

Gourlet-Fleury, S., Rossi, V., Rejou-Mechain, M., Freycon, V., Fayolle, A., Saint-André, L., Cornu, G., Gerard, J., Sarrailh, J.M., Flores, O., 2011. Environmental filtering of dense-wooded species controls above-ground biomass stored in African moist forests. Journal of Ecology 99, 981–990.

Gravel, D., Canham, C.D., Beaudet, M., and Messier, C. 2010. Shade tolerance, canopy gaps and mechanisms of coexistence of forest trees. Oikos 119, 475–484.

Herault, B., Bachelot, B., Poorter, L., Rossi, V., Bongers, F., Chave, J., Paine, C.E., Wagner, F., Baraloto, C., 2011. Functional traits shape ontogenetic growth trajectories of rain forest tree species. Journal of Ecology 99, 1431–1440.

Kunstler, G., Lavergne, S., Courbaud, B., Thuiller, W., Vieilledent, G., Zimmermann, N.E., Kattge, J., Coomes, D.A., 2012. Competitive interactions between forest trees are driven by species’ trait hierarchy, not phylogenetic or functional similarity: implications for forest community assembly. Ecology Letters 15, 831–840.

Kraft, N.J.B., Valencia, R. & Ackerly, D.D. (2008) Functional traits and niche-based tree community assembly in an Amazonian forest. Science, 322, 580–582.

Lasky, Jesse R., I. Sun, Sheng-Hsin Su, Zueng-Sang Chen, and Timothy H. Keitt. 2013. Trait-mediated Effects of Environmental Filtering on Tree Community Dynamics. Journal of Ecology. in press.

Mayfield, M.M., Levine, J.M., 2010. Opposing effects of competitive exclusion on the phylogenetic structure of communities. Ecology Letters 1085–1093.

MacArthur, R.H. & Levins, R. (1967). The limiting similarity, convergence and divergence of coexisting species. Am. Nat., 101, 377–385.

McMahon, S.M., Metcalf, C.J.E., Woodall, C.W., 2011. High-Dimensional Coexistence of Temperate Tree Species: Functional Traits, Demographic Rates, Life-History Stages, and Their Physical Context. PLoS ONE 6, e16253.

Paquette, A., Messier, C., 2010. The effect of biodiversity on tree productivity: from temperate to boreal forests. Global Ecology and Biogeography, 20, 170-180.

Poorter, L., McDonald, I., Alarcón, A., Fichtler, E., Licona, J.-C., Peña-Claros, M., Sterck, F., Villegas, Z., Sass-Klaassen, U., 2010. The importance of wood traits and hydraulic conductance for the performance and life history strategies of 42 rainforest tree species. New Phytologist 185, 481–92.

Rigling, A., Bigler, C., Eilmann, B., Feldmeyer-Christe, E., Gimmi, U., Ginzler, C., Graf, U., Mayer, P., Vacchiano, G., Weber, P., Wohlgemuth, T., Zweifel, R., Dobbertin, M., 2013. Driving factors of a vegetation shift from Scots pine to pubescent oak in dry Alpine forests. Glob Change Biol 19, 229–240.

Rüger, N. Wirth, C. Wright, J. S. & Condit, R. (2012) Functional traits explain light and size response of growth rates in tropical tree species. Ecology, 93, 2626-2636.

Sears, A.L., and Chesson, P. 2007. New methods for quantifying the spatial storage effect: an illustration with desert annuals. Ecology 88, 2240–2247.

Uriarte, M., Swenson, N.G., Chazdon, R.L., Comita, L.S., John Kress, W., Erickson, D., Forero-Montaña, J., Zimmerman, J.K., Thompson, J., 2010. Trait similarity, shared ancestry and the structure of neighbourhood interactions in a subtropical wet forest: implications for community assembly. Ecology Letters, 13, 1503–1514.

Westoby, M., Falster, D.S., Moles, A.T., Vesk, P. a., Wright, I.J., 2002. PLANT ECOLOGICAL STRATEGIES: Some Leading Dimensions of Variation Between Species. Annual Review of Ecology, Evolution, and Systematics 33, 125–159.

Wright, S.J., Kitajima, K., Kraft, N.J.B., Reich, P.B., Wright, I.J., Bunker, D.E., Condit, R., Dalling, J.W., Davies, S.J., Díaz, S., others, 2010. Functional traits and the growth-mortality trade-off in tropical trees. Ecology 91, 3664–3674.
